@@ -21,6 +21,8 @@
 #---------------------------------------------------------------------------
 from base_device_module import deviceModule
 
+# NOTE: use the device_ prefix when naming the module
+
 def getModule(m,d):
   return(device_example(m,d))
 
@@ -28,12 +30,8 @@ class device_example(deviceModule):
   """A sample modRana device-specific module"""
   
   def __init__(self, m, d):
-    ranaModule.__init__(self, m, d)
+    deviceModule.__init__(self, m, d)
     
-  def update(self):
-    # Get and set functions are used to access global data
-    self.set('num_updates', self.get('num_updates', 0) + 1)
-    #print "Updated %d times" % (self.get('num_updates'))
 
 if(__name__ == "__main__"):
   a = device_example({}, {})
